@@ -1,3 +1,4 @@
+from functools import wraps
 from typing import Callable
 
 from frozendict import frozendict
@@ -69,6 +70,7 @@ class cachedclassproperty:
 
 
 def freezeargs(fn):
+    @wraps(fn)
     def wrapper(*args, **kwargs):
         args = ((frozendict(v) if isinstance(v, dict) else v) for v in args)
         kwargs = {k: (frozendict(v) if isinstance(v, dict) else v) for k, v in kwargs.items()}
