@@ -5,6 +5,8 @@ import uuid
 from json import JSONDecodeError, JSONDecoder  # noqa
 from typing import Any, IO, Type, Union
 
+import frozendict
+
 from dimtim.interfaces import Serializable
 from dimtim.utils import duration, timezone
 
@@ -60,6 +62,9 @@ class JSONEncoder(json.JSONEncoder):
         if isinstance(o, (decimal.Decimal, uuid.UUID)):
             return str(o)
 
+        if isinstance(o, frozendict.frozendict):
+            return dict(o)
+
         if isinstance(o, Serializable):
             return o.serialize()
 
